/**********************************************************************

       Code for calculating the evolution of the Sivers function 
       from the Bochum fits  (Phys.Rev.D73,094023 (2006))
       with evolution implemented following arXiv:1110.6428.


	

	  BochumSivers(x,kt,q,fl) is a callable function that 
           returns the Sivers function with:
                   x = Bjorken-x
                   kt = transverse quark momentum (in GeV)
                   q = the hard scale (in GeV)
                   fl= flavor (1 = up quark, 2 = down quark)

	   
       In the Bochum fits, the down quark Sivers 
       function is just the negative of the up quark one. 


	  The Sivers functions here are Gaussians obtained
       with parameters depending on q and parametrized 
       previously with the FindFit routine in 
       Wolfram Mathematica. 
      
**********************************************************************/

#include <iostream>
#include <math.h>
#include "sivers.h"

using namespace std;

double fonepert(double xa,double kt2zero) {

double Mp=0.938;

return -(2*Mp*Mp / kt2zero) * (.17 * pow(xa,(.66 - 1)) * pow((1 - xa),5) ) ;
}

double gaussnormfitlowbochum (double q) {

return 1.76248/(-28.0094*q + 20.0822*q*q - 0.374729*pow(q,4) + 0.00296727*pow(q,6)); 
}

double gaussnormfithighbochum (double q) {

return 0.000141945 + 1145.69 / (-44440.5*sqrt(q) + 43335.0*q);
}

double gaussparfitbochum (double q) {


return  1.45226/log(0.557029*q*q);

}


double BochumUpSivers (double xa, double kt, double q) {


double xval = 0.1;
double Mp = 0.938;

double kt2zerovalbochum = .2 ;

double factor1 = -Mp/2.0/kt/xval;
double factor2 = fonepert(xa,kt2zerovalbochum) / fonepert(xval,kt2zerovalbochum);

if (q<=5) return factor1*factor2 * gaussnormfitlowbochum(q) * kt * exp(-gaussparfitbochum(q)*kt*kt);
else if (q>5) return factor1*factor2 * gaussnormfithighbochum(q) * kt * exp(-gaussparfitbochum(q)*kt*kt);


}

double BochumDownSivers (double xa, double kt, double q){

return -BochumUpSivers(xa,kt,q);

}


double BochumSivers(double xa, double kt, double q, int fl) {

if (fl==1) return BochumUpSivers(xa,kt,q);
else if (fl==2) return BochumDownSivers(xa,kt,q);
else {
	cout <<"Unrecognized Flavor" << endl;
	exit(1);
	}

}

