CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C       Code for calculating the evolution of the Sivers function 
C       from the Bochum fits  (Phys.Rev.D73,094023 (2006))
C       with evolution implemented following arXiv:1110.6428.
C
C
C	
C
C	  BochumSivers(x,kt,q,fl) is a callable function that 
C           returns the Sivers function with:
C                   x = Bjorken-x
C                   kt = transverse quark momentum (in GeV)
C                   q = the hard scale (in GeV)
C                   fl= flavor (1 = up quark, 2 = down quark)
C
C	   
C       In the Bochum fits, the down quark Sivers 
C       function is just the negative of the up quark one. 
C
C
C	  The Sivers functions here are Gaussians obtained
C       with parameters depending on q and parametrized 
C       previously with the FindFit routine in 
C       Wolfram Mathematica. 
C      
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



      real*8 function BochumSivers(xval,ktval,qval,fl)
      implicit none
      real*8 xval,qval,ktval
      real*8 sivvalup, sivvaldown
      real*8 BochumUpSivers
      integer num, fl

      if(fl.eq.1) then

     	BochumSivers = BochumUpSivers(xval,ktval,qval)
      
      else
      if(fl.eq.2) then
      
      BochumSivers = -1.0d0*BochumUpSivers(xval,ktval,qval)
      else
      PRINT *, 'Unrecognized Flavor'	
      endif
      endif      

      return
     
      end
     
  
      real*8 function BochumUpSivers(x,kt,q)
      implicit none
      real*8 x,kt,q
C	BASIC PARAMETERS FOR CALCULATION.
      real*8 CF,TF,C1,bmax,MP,pi,e
      real*8 xval,g2val,Qinitval,Q0val,x0
      real*8 kt2zeroval,gaussnormfitlow
      real*8 gaussnormfithigh,gaussparfit
      real*8 fonepert,fonepert0
      CF=4.0d0/3.0d0
      TF=1.0d0/2.0d0
      C1=1.123d0
      pi=3.1415926536d0
      MP=0.938d0
      e=2.7182818284d0
      g2val = 0.68d0
      Qinitval = Sqrt(2.4d0)
      Q0val = 3.2d0
      x0 = 0.1d0
C	ANALYTIC FITS.
      kt2zeroval = 0.2d0 - 2.0d0*g2val*log(Qinitval/Q0val)
      fonepert = -(2*(MP**(2.0d0))/kt2zeroval)
     &*(0.17d0*(x**(0.66d0 - 1.0d0)))
     &*(1.0d0 - x)**5.0d0     
      fonepert0 = -(2*(MP**(2.0d0))/kt2zeroval)
     &*(0.17d0*(x0**(0.66d0 - 1.0d0)))
     &*(1.0d0 - x0)**5.0d0    
      gaussnormfitlow = 1.76248d0/(-28.0094d0*q 
     &+ 20.0822d0*(q**2.0d0) - 0.374729d0*(q**4.0d0) 
     &+ 0.00296727d0*(q**6.0d0))      
      gaussnormfithigh = 0.000141945d0 
     &+ 1145.69d0/(-44440.5d0*Sqrt(q) + 43335.0d0*q)	
      gaussparfit = 1.45226d0 / log(0.557029d0*(q**2))
      if(q.lt.5.0d0) then
      bochumupsivers = (-MP / (2.0d0*kt*x0))*(fonepert/fonepert0)
     &*gaussnormfitlow*kt*e**(-gaussparfit*kt**(2.0d0)) 
      else
      bochumupsivers = (-MP / (2.0d0*kt*x0))*(fonepert/fonepert0)
     &*gaussnormfithigh*kt*e**(-gaussparfit*kt**(2.0d0))
      end if      

      return
      end
      
  

